% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 740.222642817832930 ; 704.798370212233410 ];

%-- Principal point:
cc = [ 319.500000000000000 ; 239.500000000000000 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ 0.000000000000000 ; 0.000000000000000 ; 0.000000000000000 ; 0.000000000000000 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [   NaN ;   NaN ];

%-- Principal point uncertainty:
cc_error = [   NaN ;   NaN ];

%-- Skew coefficient uncertainty:
alpha_c_error =   NaN;

%-- Distortion coefficients uncertainty:
kc_error = [   NaN ;   NaN ;   NaN ;   NaN ;   NaN ];

%-- Image size:
nx = 640;
ny = 480;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 18;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 0;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ 2.697561e+000 ; 1.738460e+000 ; -3.616745e-001 ];
Tc_1  = [ -1.096871e+001 ; -1.069727e+001 ; 4.501200e+001 ];
omc_error_1 = [ NaN ; NaN ; NaN ];
Tc_error_1  = [ NaN ; NaN ; NaN ];

%-- Image #2:
omc_2 = [ 2.561106e+000 ; 2.016730e+000 ; -2.945044e-001 ];
Tc_2  = [ -1.002748e+001 ; -1.275349e+001 ; 5.420803e+001 ];
omc_error_2 = [ NaN ; NaN ; NaN ];
Tc_error_2  = [ NaN ; NaN ; NaN ];

%-- Image #3:
omc_3 = [ 2.474666e+000 ; 1.957995e+000 ; -2.710129e-001 ];
Tc_3  = [ -1.051101e+001 ; -1.799016e+001 ; 6.980536e+001 ];
omc_error_3 = [ NaN ; NaN ; NaN ];
Tc_error_3  = [ NaN ; NaN ; NaN ];

%-- Image #4:
omc_4 = [ 2.428034e+000 ; 1.914337e+000 ; -2.713108e-001 ];
Tc_4  = [ -9.878589e+000 ; -1.939067e+001 ; 8.639522e+001 ];
omc_error_4 = [ NaN ; NaN ; NaN ];
Tc_error_4  = [ NaN ; NaN ; NaN ];

%-- Image #5:
omc_5 = [ 2.443861e+000 ; 1.910861e+000 ; -2.803729e-001 ];
Tc_5  = [ -1.116119e+001 ; -2.310961e+001 ; 8.235376e+001 ];
omc_error_5 = [ NaN ; NaN ; NaN ];
Tc_error_5  = [ NaN ; NaN ; NaN ];

%-- Image #6:
omc_6 = [ 2.522381e+000 ; 1.829740e+000 ; -3.716256e-001 ];
Tc_6  = [ -8.890741e+000 ; -1.227582e+001 ; 8.793013e+001 ];
omc_error_6 = [ NaN ; NaN ; NaN ];
Tc_error_6  = [ NaN ; NaN ; NaN ];

%-- Image #7:
omc_7 = [ 2.547378e+000 ; 1.880040e+000 ; -3.945193e-001 ];
Tc_7  = [ -6.880995e+000 ; -4.444739e+000 ; 4.507018e+001 ];
omc_error_7 = [ NaN ; NaN ; NaN ];
Tc_error_7  = [ NaN ; NaN ; NaN ];

%-- Image #8:
omc_8 = [ 2.437000e+000 ; 1.779449e+000 ; 1.589478e-001 ];
Tc_8  = [ -3.570128e+000 ; 5.516994e+000 ; 4.601599e+001 ];
omc_error_8 = [ NaN ; NaN ; NaN ];
Tc_error_8  = [ NaN ; NaN ; NaN ];

%-- Image #9:
omc_9 = [ 2.469903e+000 ; 1.875861e+000 ; -3.577447e-001 ];
Tc_9  = [ -9.950606e+000 ; -1.351738e+001 ; 5.433675e+001 ];
omc_error_9 = [ NaN ; NaN ; NaN ];
Tc_error_9  = [ NaN ; NaN ; NaN ];

%-- Image #10:
omc_10 = [ 2.517412e+000 ; 1.887826e+000 ; -3.894870e-001 ];
Tc_10  = [ -7.265087e+000 ; -5.611499e+000 ; 4.398070e+001 ];
omc_error_10 = [ NaN ; NaN ; NaN ];
Tc_error_10  = [ NaN ; NaN ; NaN ];

%-- Image #11:
omc_11 = [ 1.512736e+000 ; 2.594130e+000 ; 7.057755e-002 ];
Tc_11  = [ 8.015496e-001 ; -4.563346e+000 ; 4.125822e+001 ];
omc_error_11 = [ NaN ; NaN ; NaN ];
Tc_error_11  = [ NaN ; NaN ; NaN ];

%-- Image #12:
omc_12 = [ 1.460855e+000 ; 2.683375e+000 ; -2.910084e-002 ];
Tc_12  = [ -1.792689e-001 ; -9.081293e+000 ; 4.896430e+001 ];
omc_error_12 = [ NaN ; NaN ; NaN ];
Tc_error_12  = [ NaN ; NaN ; NaN ];

%-- Image #13:
omc_13 = [ 1.616359e+000 ; 2.884197e+000 ; -2.205301e-001 ];
Tc_13  = [ -3.308653e-001 ; -7.668257e+000 ; 5.378737e+001 ];
omc_error_13 = [ NaN ; NaN ; NaN ];
Tc_error_13  = [ NaN ; NaN ; NaN ];

%-- Image #14:
omc_14 = [ 1.578142e+000 ; 2.652491e+000 ; -3.877672e-001 ];
Tc_14  = [ -4.142639e+000 ; -1.742284e+001 ; 5.961566e+001 ];
omc_error_14 = [ NaN ; NaN ; NaN ];
Tc_error_14  = [ NaN ; NaN ; NaN ];

%-- Image #15:
omc_15 = [ 1.481991e+000 ; 2.498259e+000 ; 1.898157e-001 ];
Tc_15  = [ 1.940019e+000 ; -1.871685e+000 ; 3.748971e+001 ];
omc_error_15 = [ NaN ; NaN ; NaN ];
Tc_error_15  = [ NaN ; NaN ; NaN ];

%-- Image #16:
omc_16 = [ 1.483399e+000 ; 2.482620e+000 ; 1.832159e-001 ];
Tc_16  = [ 2.116411e+000 ; -1.036787e+000 ; 4.876855e+001 ];
omc_error_16 = [ NaN ; NaN ; NaN ];
Tc_error_16  = [ NaN ; NaN ; NaN ];

%-- Image #17:
omc_17 = [ 2.840702e+000 ; -1.027266e+000 ; 2.044244e+000 ];
Tc_17  = [ 1.260379e+000 ; 9.995271e+000 ; 8.080075e+000 ];
omc_error_17 = [ NaN ; NaN ; NaN ];
Tc_error_17  = [ NaN ; NaN ; NaN ];

%-- Image #18:
omc_18 = [ 1.681806e+000 ; 2.397281e+000 ; -7.581872e-002 ];
Tc_18  = [ 3.436090e+000 ; -1.120275e+001 ; 4.378694e+001 ];
omc_error_18 = [ NaN ; NaN ; NaN ];
Tc_error_18  = [ NaN ; NaN ; NaN ];

